@@ -30,9 +30,7 @@
 #include <QModelIndex>
 #include <QSet>
 
-namespace IncidenceEditorNG
-{
-
+namespace IncidenceEditorNG {
 class ResourceModel : public QAbstractItemModel
 {
     Q_OBJECT
@@ -46,25 +44,23 @@ public:
         FullName
     };
 
-    ResourceModel(const QStringList &headers,
-                  QObject *parent = nullptr);
+    ResourceModel(const QStringList &headers, QObject *parent = nullptr);
     ~ResourceModel();
 
-    QVariant data(const QModelIndex &index, int role) const Q_DECL_OVERRIDE;
+    QVariant data(const QModelIndex &index, int role) const override;
     QVariant headerData(int section, Qt::Orientation orientation,
-                        int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+                        int role = Qt::DisplayRole) const override;
 
     QModelIndex index(int row, int column,
-                      const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    QModelIndex parent(const QModelIndex &index) const Q_DECL_OVERRIDE;
+                      const QModelIndex &parent = QModelIndex()) const override;
+    QModelIndex parent(const QModelIndex &index) const override;
 
-    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    int columnCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    int columnCount(const QModelIndex &parent = QModelIndex()) const override;
 
-    Qt::ItemFlags flags(const QModelIndex &index) const Q_DECL_OVERRIDE;
+    Qt::ItemFlags flags(const QModelIndex &index) const override;
 
-    bool removeRows(int position, int rows,
-                    const QModelIndex &parent = QModelIndex()) Q_DECL_OVERRIDE;
+    bool removeRows(int position, int rows, const QModelIndex &parent = QModelIndex()) override;
 private:
     ResourceItem *getItem(const QModelIndex &index) const;
 
@@ -104,7 +100,7 @@ private:
      */
     QSet <ResourceItem::Ptr> ldapCollections;
 
-    /* Cached searchString (setted by startSearch(QString))
+    /* Cached searchString (set by startSearch(QString))
      *
      */
     QString searchString;
@@ -130,6 +126,5 @@ private:
      */
     void slotLDAPSearchData(const KLDAP::LdapResultObject::List &);
 };
-
 }
 #endif // RESOURCEMODEL_H
